<?php
$lang['statreport_linesperpage'] = 'Linjer per side i statistikkrapporten';
$lang['banner'] = 'Banner annonse';
$lang['of'] = 'av';
$lang['page'] = 'Side';
$lang['generated'] = 'Generert';
$lang['generated_by'] = 'Generert av';
$lang['desc_stats_report'] = 'En rapport som illustrerer antall visninger og klikk-via treff fra Banners modulen';
$lang['title_stats_report'] = 'Banner statistikkrapport';
$lang['view_statistics'] = 'Vis statistikk';
$lang['msg_new_window'] = 'Lager et nytt vindu';
$lang['statreport_template'] = 'Statistikk rapportmal';
$lang['your_ad_here'] = 'Din annonse kunne v&aelig;rt her';
$lang['prompt_dflt_image'] = 'Standard bilde';
$lang['prompt_dflt_url'] = 'Standard URL';
$lang['info_dflt_image'] = 'Angi et bildenavn (relativt til uploads katalogen) til et bilde som skal brukes n&aring;r ingen bannere er gyldige for visning';
$lang['prompt_hidefrombots'] = 'Utelukk robotter fra innrykk telling';
$lang['help_param_action'] = 'Oppgi oppf&oslash;rselen for modulen. Mulige verdier er &quot;default&quot; og &quot;list&quot;. default handlingen benyttes for &aring; vise et enkelt banner i forhold til spesifisert kriterie. list handlingen benyttes til &aring; vise alle bannere av en spesifisert kategori eller kategori id';
$lang['help_param_category'] = 'I standard handlingen, vil denne parameter bli benyttet for &aring; spesifisere navnet p&aring; kategorien hvor et enkelt banner skal vises fra. I list handlingen er denne parameter p&aring;krevd for &aring; spesifisere navnet p&aring; hvilken kategori alle bannerne skal vises fra';
$lang['help_param_mode'] = 'Denne parameter blir kun benyttet i standard handlingen, hvor den spesifiserer m&aring;ten som bannere blir valgt fra den spesifiserte kategorien. Den  eneste verdien er &quot;sequential&quot; som indikerer at modulen skal velge det neste ikke-utl&oslash;pte banneret som er minst vist. Ved &aring; ikke spesifisere denne parameter vil resultatet bli at et tilfeldig banner blir vist';
$lang['help_param_name'] = 'Denne parameter benyttes kun i default (standard) handlingen. Den spesifiserer et absolutt navn p&aring; et banner som skal lastes. Men, om banneret er ugyldig (at antall visninger har blitt n&aring;dd, ELLER det har utl&oslash;pt), ingenting vil bli vist.';
$lang['bannerlist_template'] = 'Banner listemal';
$lang['info_bannerlist_template'] = 'Om benyttet med list handlingen, vil denne mal kontrollere visningen av alle bannere i den valgte kattegorien';
$lang['none'] = 'Ingen';
$lang['error_invalid_dates'] = 'Feil! Ugyldige datoer';
$lang['editbanner'] = 'Rediger banner';
$lang['start_date'] = 'Startdato';
$lang['atttext'] = 'p&aring;';
$lang['template'] = 'Mal';
$lang['default_template'] = 'Standard kategorimal';
$lang['reset_template'] = 'Tilbakestill mal til standard';
$lang['error_banners'] = 'Ingen banner';
$lang['error_bannerexists'] = 'Banner med dette navnet eksisterer allerede';
$lang['accessdenied'] = 'Tilgang nektet. Vennligst sjekk rettigheter.';
$lang['addbanner'] = 'Legg til banner';
$lang['addcategory'] = 'Legg til kategori';
$lang['areyousure'] = 'Er du sikker?';
$lang['banners'] = 'Bannere';
$lang['cancel'] = 'Avbryt';
$lang['categories'] = 'Kategorier';
$lang['category'] = 'Kategori';
$lang['created'] = 'Opprettet';
$lang['date'] = 'Dato';
$lang['delete'] = 'Slett';
$lang['description'] = 'Beskrivelse';
$lang['edit'] = 'Rediger';
$lang['editcategory'] = 'Rediger kategori';
$lang['error'] = 'Feil!';
$lang['error_banerexists'] = 'Banner med dette navnet eksisterer allerede';
$lang['error_categorynotempty'] = 'Feil: Kategorien er ikke tom!';
$lang['error_dberror'] = 'Feil: Databasefeil!';
$lang['error_emptybannername'] = 'Feil: Mangler Banner navn!';
$lang['error_emptycategory'] = 'Feil: Tom kategori!';
$lang['error_insufficientparams'] = 'Feil: Ikke nok informasjon!';
$lang['error_nocategories'] = 'Feil: Ingen kategori funnet!';
$lang['error_noresults'] = 'Ingen banner samsvarer med foresp&oslash;rsel';
$lang['error_textorimage'] = 'Oppgi URL og IMAGE eller TEXT, ikke begge';
$lang['expires'] = 'Utl&oslash;per';
$lang['friendlyname'] = 'Administrer bannere';
$lang['height'] = 'H&oslash;yde';
$lang['hits'] = 'Treff';
$lang['href_text'] = 'Link tekst';
$lang['id'] = 'ID ';
$lang['image'] = 'Bilde';
$lang['image_text'] = 'Alt. bilde tekst';
$lang['impressions'] = 'Innrykk';
$lang['info_href_text'] = 'Ekstra tekst for link taggen.  Denne tekst plasseres i link taggen bokstavelig talt';
$lang['info_image'] = 'Spesifiser en fil relativt til din opplastingsmappe';
$lang['info_image_text'] = 'Ekstra tekst for bilde taggen';
$lang['info_max_hits'] = 'Bruk 0 for ubegrensede treff';
$lang['info_max_impressions'] = 'Bruk 0 for ubegrensede innrykk';
$lang['installed'] = 'Modul versjon %s installert.';
$lang['ipaddress'] = 'IP adresse';
$lang['max_hits'] = 'Maksimum treff';
$lang['max_impressions'] = 'Maksimum innrykk';
$lang['name'] = 'Navn';
$lang['never'] = 'Aldri';
$lang['postinstall'] = 'Etter installasjons melding, f.eks. husk &aring; sette &quot;Manage Banners&quot; rettigheter for &aring; bruke denne modulen';
$lang['postuninstall'] = 'Banner modul avinstallert og alle database tabeller fjernet. Trist &aring; se deg g&aring;.';
$lang['preferences'] = 'Innstillinger';
$lang['prefsupdated'] = 'Modul innstillinger oppdatert.';
$lang['prompt_categorydesc'] = 'Kategori beskrivelse';
$lang['prompt_categoryname'] = 'Kategori navn';
$lang['prompt_imageheight'] = 'Bilde h&oslash;yde';
$lang['prompt_imagewidth'] = 'Bilde bredde';
$lang['prompt_subnet_exclusions'] = 'Ekskluder disse subnett fra all statistikk innhenting';
$lang['prompt_upload_category'] = 'Kategori (Opplastings modul)';
$lang['prompt_upload_file'] = 'Bilde (Opplastings modul)';
$lang['selectcategory'] = 'Velg kategori';
$lang['submit'] = 'Utf&oslash;r';
$lang['text'] = 'Tekst';
$lang['title_mod_admin'] = 'Modul administrasjonspanel';
$lang['title_mod_prefs'] = 'Modul innstillinger';
$lang['uninstalled'] = 'Modul avinstallert';
$lang['upgraded'] = 'Modul oppgradert til versjon %s.';
$lang['url'] = 'URL ';
$lang['width'] = 'Bredde';
$lang['title_admin_panel'] = 'Banner modul';
$lang['moddescription'] = 'en modul for &aring; h&aring;ndtere roterende bannere';
$lang['welcome_text'] = '<p>Velkommen til Banner behandlings modulens administrasjons seksjon. </p>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>This banner manages numerous categories of banners, tracks hits, impressions, and expiry dates, and randomly selects from all available and valid banners for one to display</p>
<h3>How Do I Use It</h3>
<p>To use this module, place the module code in a page or template using the smarty tag {Banners category=&quot;categoryname&quot;}</p> 
<p>You must also upload banners to a suitable directory within the uploads directory and must use the admin panel interface to add banners to the database.</p
<p>You can also output a list of all of the valid banners within a category by specifying the action=&quot;list&quot; parameter on the tag.  See more information about this below.</p>
<h3>Hint</h3>
<p>The uploads module and the banners module work well together.  You can create a &quot;banners&quot; category in the uploads module, and upload your banner images there, then specify &quot;banners/<filename>&quot; when adding a banner in the banners module.</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguy&#039;s
module homepage at <a href="http://techcom.dyndns.org">techcom.dyndns.org</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
$lang['utmz'] = '156861353.1300226369.3692.81.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/feature_request/list/6';
$lang['utma'] = '156861353.179052623084110100.1210423577.1301237988.1301251141.3715';
$lang['qca'] = '1210971690-27308073-81952832';
$lang['utmb'] = '156861353.1.10.1301251141';
$lang['utmc'] = '156861353';
?>